//=============================================================================================================
//=========================================CPUtils SECTION=====================================================
//=============================================================================================================

function CPUtils() {
}

CPUtils.uniqId = function () {
    return 'u'+Math.round(new Date().getTime() + (Math.random() * 100));
}

CPUtils.getElementPositionAndSize = function( element ) {
    var $selector = $( element );
    return $.extend({}, $selector.offset(), 
        { 
            width: $selector.width(), 
            outerWidth : $selector.outerWidth(),
            outerWidthMargin : $selector.outerWidth( true ),
            height: $selector.height(),
            outerHeight : $selector.outerHeight(),
            outerHeightMargin : $selector.outerHeight( true ),
            padding : { 
                top : parseInt($selector.css('padding-top')),
                right : parseInt($selector.css('padding-right')),
                bottom : parseInt($selector.css('padding-bottom')),
                left : parseInt($selector.css('padding-left')),
            },
            border : {
                top : parseInt($selector.css('border-top-width')),
                right : parseInt($selector.css('border-right-width')),
                bottom : parseInt($selector.css('border-bottom-width')),
                left : parseInt($selector.css('border-left-width')),
            },
            margin : {
                top : parseInt($selector.css('margin-top')),
                right : parseInt($selector.css('margin-right')),
                bottom : parseInt($selector.css('margin-bottom')),
                left : parseInt($selector.css('margin-left')),
            }
        }
    );
}

CPUtils.getViewDetails = function() {
    if(this.view_details) return this.view_details;
    this.updateViewDetails();
    return this.view_details;
}

CPUtils.updateViewDetails = function() {
     this.view_details = {
        document : {
            width: $(document).width(),
            height: $(document).height(),        
        },
        view : {
            width: $(window).width(),
            height: $(window).height(), 
        }
    }
}

CPUtils.getDiffrents = function(element, element_parent) {
    if(typeof element_parent === 'undefined' || element_parent === false ) return {top: 0, bottom: 0, left: 0, right: 0};
    
    var element_details = this.getElementPositionAndSize(element);
    var element_parent_details = this.getElementPositionAndSize(element_parent);
    
    return {
        top: element_details.top - element_parent_details.top,
        bottom: element_parent_details.outerHeight - (element_details.outerHeight + element_details.top - element_parent_details.top),
        left: element_details.left - element_parent_details.left,
        right: element_parent_details.outerWidth - (element_details.outerWidth + element_details.left - element_parent_details.left),
    }
}

//=============================================================================================================
//=========================================CPContainer SECTION=================================================
//=============================================================================================================
function CPContainer(content, x, y ) {
    this.id = CPUtils.uniqId();
    this.x = typeof x !== 'undefined' ? x : 0;
    this.y = typeof y !== 'undefined' ? y : 0;

    this.$this = $( "<div/>", {
        id: this.id,
        html: content,
    }).offset({left: x, top: y}).addClass("CPContainer").appendTo( "body" ).hide();
    
    this.details = CPUtils.getElementPositionAndSize( this.$this );
}

CPContainer.prototype.show = function() {
    this.$this.show();
    return this;
}

CPContainer.prototype.hide = function() {
    this.$this.hide();
    return this;
}

CPContainer.prototype.getJQueryObject = function() {
    return this.$this;
}

CPContainer.prototype.setPosition = function(x, y) {
    this.$this.offset({left: x, top: y});
    this.x = x; this.y = y;
    return this;
}

CPContainer.prototype.setContent = function(content) {
    this.$this.html(content);
    this.refreshDetails();
    return this;
}

CPContainer.prototype.refreshDetails = function() {
    this.details = CPUtils.getElementPositionAndSize( this.$this );
    return this;
}
//=============================================================================================================
//=========================================CPArrow SECTION=====================================================
//=============================================================================================================
function CPArrow(direction, x, y) {
    this.id = CPUtils.uniqId();
    this.x = typeof x !== 'undefined' ? x : 0;
    this.y = typeof y !== 'undefined' ? y : 0;
    this.direction = typeof direction !== 'undefined' ? direction : 'up';
    
    this.$this = $( "<div/>", {
        id: this.id,
    }).offset({left: x, top: y}).addClass("CPArrow").addClass(this.direction).appendTo( "body" ).hide();
    
    this.details = CPUtils.getElementPositionAndSize( this.$this );
}

CPArrow.prototype.show = function() {
    this.$this.show();
    return this;
}

CPArrow.prototype.hide = function() {
    this.$this.hide();
    return this;
}

CPArrow.prototype.getJQueryObject = function() {
    return this.$this;
}

CPArrow.prototype.pointTo = function(element, from, shift) {
    shift = typeof shift !== 'undefined' ? shift : 0;
    var details = CPUtils.getElementPositionAndSize( element );
    
    if(from == "top") this.setDirection("down").setPosition(details.left + details.outerWidth / 2 - this.details.outerWidth / 2, details.top - this.details.outerHeight - shift);
    else if(from == "bottom") this.setDirection("up").setPosition(details.left + details.outerWidth / 2 - this.details.outerWidth / 2, details.top + details.outerHeight + shift);
    else if(from == "left") this.setDirection("right").setPosition(details.left - this.details.outerWidth - shift, details.top + details.outerHeight / 2 - this.details.outerHeight / 2);
    else if(from == "right") this.setDirection("left").setPosition(details.left + details.outerWidth + shift, details.top + details.outerHeight / 2 - this.details.outerHeight / 2);
}

CPArrow.prototype.setDirection = function(direction) {
    this.$this.removeClass(this.direction).addClass(direction);
    this.direction = direction;
    this.refreshDetails();
    return this;
}

CPArrow.prototype.setPosition = function(x, y) {
    this.$this.offset({left: x, top: y});
    this.x = x; this.y = y;
    return this;
}

CPArrow.prototype.refreshDetails = function() {
    this.details = CPUtils.getElementPositionAndSize( this.$this );
    return this;
}

//=============================================================================================================
//=========================================CPTooltip SECTION===================================================
//=============================================================================================================

function CPTooltip(content, $element, horizontal, $element_parent) {
    this.horizontal = typeof horizontal !== 'undefined' ? horizontal : false;
    this.$element = $element;
    this.$element_parent = typeof $element_parent !== 'undefined' ? $element_parent : false;
    this.arrow = new CPArrow(this.horizontal?"left":"up");
    this.container = new CPContainer(content);
    
    this.refresh();
}

CPTooltip.prototype.refresh = function() {
    this.container.refreshDetails();
    if(this.horizontal) this.refreshHorizontal();
    else this.refreshVertical();
    return this;
}

CPTooltip.prototype.refreshHorizontal = function() { //poziomo
    var element_details = CPUtils.getElementPositionAndSize( this.$element );
    var view_details = CPUtils.getViewDetails();
    var tooltip_size = {
        width: this.container.details.outerWidth + this.arrow.details.outerWidth,
        height: this.container.details.outerHeight,
    }
    var diff = CPUtils.getDiffrents(this.$element, this.$element_parent);
    
    var y = element_details.top + element_details.outerHeight / 2 - tooltip_size.height / 2;
    if(y + tooltip_size.height > view_details.document.height) y -= (y + tooltip_size.height - view_details.document.height);
    if(y < 0) y = 0;
    var x = 0;
    
    if( tooltip_size.width + element_details.outerWidth + element_details.left + diff.right > view_details.document.width 
            && tooltip_size.width + diff.left < element_details.left) {
        this.arrow.pointTo(this.$element, "left", diff.left);
        x = element_details.left - tooltip_size.width - diff.left;
    } else {
        this.arrow.pointTo(this.$element, "right", diff.right);
        x = element_details.left + element_details.outerWidth + this.arrow.details.outerWidth + diff.right;
    }
    
    this.container.setPosition(x, y);
    return this;
}

CPTooltip.prototype.refreshVertical = function() { //pionowo
    var element_details = CPUtils.getElementPositionAndSize( this.$element );
    var view_details = CPUtils.getViewDetails();
    var tooltip_size = {
        width: this.container.details.outerWidth,
        height: this.container.details.outerHeight + this.arrow.details.outerHeight,
    }
    var diff = CPUtils.getDiffrents(this.$element, this.$element_parent);
    
    var x = element_details.left + element_details.outerWidth / 2 - tooltip_size.width / 2;
    if(x + tooltip_size.width > view_details.document.width) x -= (x + tooltip_size.width - view_details.document.width);
    if(x < 0) x = 0;
    var y = 0;
    
    if( tooltip_size.height + element_details.outerHeight + element_details.top + diff.bottom > view_details.document.height 
            && tooltip_size.height + diff.top < element_details.top) {
        this.arrow.pointTo(this.$element, "top", diff.top);
        y = element_details.top - tooltip_size.height - diff.top;
    } else {
        this.arrow.pointTo(this.$element, "bottom", diff.bottom);
        y = element_details.top + element_details.outerHeight + this.arrow.details.outerHeight + diff.bottom;
    }
    
    this.container.setPosition(x, y);
    return this;
}

CPTooltip.prototype.show = function() {
    this.arrow.show();
    this.container.show();
    this.refresh();
    return this;
}

CPTooltip.prototype.hide = function() {
    this.arrow.hide();
    this.container.hide();
    return this;
}

CPTooltip.prototype.setContent = function(content) {
    CPUtils.updateViewDetails();
    this.container.setContent(content);
    if(this.container.$this.is(":visible")) this.refresh();
    return this;
}

CPTooltip.prototype.getID = function() {
    return this.container.id;
}

CPTooltip.prototype.remove = function() {
    this.arrow.$this.remove();
    this.container.$this.remove();
    return this;
}
//=============================================================================================================
//=========================================ClientsProfiler SECTION=============================================
//=============================================================================================================

function ClientsProfiler() {
    this.tooltips = [];
    this.timer = 0;
    
    this.loader_html = "<img id=\"mg_loader\" style=\"text-align: center; \" src=\"../modules/addons/client_profiler_viewer/views/assets/images/loadingsml.gif\" />";       
}

ClientsProfiler.prototype.addTooltipToList = function(tooltip, parent_tooltip_id) {
    this.tooltips[tooltip.getID()] = {
        tooltip: tooltip,
        parent_id: typeof parent_tooltip_id !== 'undefined' ? parent_tooltip_id : false
    }
    return this;
}

ClientsProfiler.prototype.addMainTooltip = function(content, $element) {
    this.hideTolltips();
    var tooltip = new CPTooltip(content, $element);
    this.addTooltipToList(tooltip).saveCache(tooltip.getID(), $element).showTooltip(tooltip.getID());
    return tooltip.getID();
}

ClientsProfiler.prototype.addTooltipDetails = function(content, $element, parent_id, widget) {
    this.hideDetails();
    var tooltip = new CPTooltip(content, $element, true, $("#"+parent_id));
    tooltip.container.$this.addClass("details").attr("data-widget", widget);
    this.addTooltipToList(tooltip, parent_id).saveCache(tooltip.getID(), $element).showDetails(tooltip.getID());
    return tooltip.getID();
}

ClientsProfiler.prototype.saveCache = function(uid, $element) {
    $element.attr('data-cpid', uid);
    return this;
}

ClientsProfiler.prototype.hideTolltips = function(skip_uid) {
    for(uid in this.tooltips) 
        if(uid!=skip_uid) {
            this.tooltips[uid].tooltip.hide();
            if(this.tooltips[uid].parent_id !== false) $(".CPContainer div.wmc[data-cpid=" + uid + "] div.widget-details-button").html("+");
        }
    return this;
}

ClientsProfiler.prototype.hideDetails = function(skip_uid) {
    for(uid in this.tooltips) 
        if(uid!=skip_uid && this.tooltips[uid].parent_id !== false) {
            this.tooltips[uid].tooltip.hide();
            $(".CPContainer div.wmc[data-cpid=" + uid + "] div.widget-details-button").html("+");
        }
    return this;
}

ClientsProfiler.prototype.showTooltip = function(uid) {
    this.clearTimer().hideTolltips(uid).tooltips[uid].tooltip.show();
    return this;
}

ClientsProfiler.prototype.showDetails = function(uid) {
    this.clearTimer().hideDetails(uid).tooltips[uid].tooltip.show();
    return this;
}

ClientsProfiler.prototype.getLinkDetails = function ( $a ) {
    var link  = $a.attr('href');
    if(typeof $a.attr('href') == "undefined") return {isLink: false, isClientLink: false, clientID: false, cacheID: false};
    var split = link.split('?');
    
    return {
        isLink: typeof $a.attr('href') !== "undefined" ? true : false,
        isClientLink: (split[0] !== 'clientssummary.php' || $a.text() === 'Summary' || $a.attr('id') === 'summary-reset-password' || $a.text().replace(/ /g, '') === 'ActivateasAffiliate')?false:true,
        clientID: (typeof split[1] !== "undefined") ? split[1].split('=')[1] : false,
        cacheID: typeof $a.attr('data-cpid') !== "undefined" ? $a.attr('data-cpid') : false,
    }
}

ClientsProfiler.prototype.startTimer = function (time) {
    var t = this;
    window.clearTimeout(this.timer);
    this.timer = window.setTimeout(function(){
        t.hideTolltips();
    }, time);
    return this;
}

ClientsProfiler.prototype.clearTimer = function () {
    window.clearTimeout(this.timer);
    return this;
}

ClientsProfiler.prototype.setTooltipContent = function (uid, content) {
    this.tooltips[uid].tooltip.setContent(content);
    return this;
}

ClientsProfiler.prototype.setDetailsParentContent = function (uid, content) {
    this.tooltips[this.tooltips[uid].parent_id].tooltip.setContent(content);
}

ClientsProfiler.prototype.setWidgetContent = function (uid, widget, content) {
    var tp = this.tooltips[this.tooltips[uid].parent_id].tooltip;
    $("div.wmc[data-widget=" + widget +"] div.widget-output", tp.container.$this).html(content);
    tp.refresh();
    var athis = this;
    setTimeout(function() {
        athis.tooltips[uid].tooltip.refresh();
    }, 300)
    
}

ClientsProfiler.prototype.removeTooltip = function (rid) {
    for(uid in this.tooltips) 
        if(uid==rid || this.tooltips[uid].parent_id == rid) {
            this.tooltips[uid].tooltip.remove();
            delete this.tooltips[uid];
        }
    
    $("[data-cpid=" + rid + "]").removeAttr("data-cpid");
    return this;
}

ClientsProfiler.prototype.doAction = function (button) {
    var toll_tip = button.parents('.CPContainer').first();
    var profiler = this;
    var details = button.parents('.CPContainer.details').length;
    var subaction = button.data('subact');
    var widget = toll_tip.data('widget');
    var id = toll_tip.attr('id');
    var clientid = toll_tip.data('clientid');
    
    var pathArray = {};
    pathArray['subact'] = subaction;
    pathArray['widget'] = widget;
    pathArray['id']     = clientid;
    
    
    var noloader = button.data("noloader");
    if(typeof noloader == 'undefined' || !noloader) {
        this.appendLoader(button);
    }

    var refresh_details = button.data("refresh-details");
    if(typeof refresh_details != 'undefined') {
        pathArray['refresh_details'] = 1;
    }
    
    var refresh_widget = button.data("refresh-widget");
    if(typeof refresh_widget != 'undefined') {
        pathArray['refresh_widget'] = 1;
    }

    var rawData = '';
    
    var formid = button.data("formid");
    if(typeof formid != 'undefined') {
        if(typeof button.data("raw") != "undefined") {
            rawData = $('#' + formid + ' :input').serialize();
        } else {
            pathArray = $.extend({}, pathArray, profiler.queryToArray($('#' + formid + ' :input').serialize()));
        }
    }
    
    var formclass = button.data("formclass");
    if(typeof formclass != 'undefined') {
        if(typeof button.data("raw") != "undefined") {
            rawData = $('.' + formclass + ' :input', toll_tip).serialize();
        } else {
            pathArray = $.extend({}, pathArray, profiler.queryToArray($('.' + formclass + ' :input', toll_tip).serialize()));
        }
    }

    var additional_query = button.data("query");
    if(typeof additional_query != 'undefined' && additional_query.length > 0) {
        pathArray = $.extend({}, pathArray, profiler.queryToArray(additional_query));
    }
    
    pathArray['ajax'] = 1;
    $.ajax({
        type: "POST",
        url: '../modules/addons/client_profiler_viewer/caller.php?module=client_profiler_viewer&page=profiler&ajax=1&act=subaction&ajax=1' ,
        data: profiler.arrayToQuery(pathArray) + '&' + rawData ,
        //async: false
    })
    .done(function( ret ) {
        var obj = $.parseJSON( ret );

        if(obj.result == 1) {
            if(typeof obj.action.output.details_content != 'undefined') {
                profiler.setTooltipContent(id, obj.action.output.details_content);
            }
            
            if(typeof obj.action.output.widget_content != 'undefined') {
                profiler.setWidgetContent(id, widget, obj.action.output.widget_content);
            }

            if(typeof obj.action.output.popup != 'undefined') {
                profiler.showPopup(obj.action.output.popup);
            }

            if(typeof obj.action.output.open_window != 'undefined') {
                profiler.openNewWindow(obj.action.output.open_window);
            }

            profiler.setAlerts(obj.action.output.error, obj.action.output.info, toll_tip);
            profiler.setAlerts(obj.action.error, obj.action.info, toll_tip);
            
        } else {
            alert(obj.errormsg);
        }

    })
    .always(function() {
        profiler.removeLoader();
    });
    
}

ClientsProfiler.prototype.queryToArray = function (query) {
    var queryParameters = {}, queryString = query, re = /([^&=]+)=([^&]*)/g, m;
    
    while (m = re.exec(queryString)) {
        if(typeof m[2] == 'string') {
            m[2] = m[2].replace(/\+/g," ").replace(/%2b/g,'+')
        }
        queryParameters[decodeURIComponent(m[1])] = decodeURIComponent(m[2]);
    }
    return queryParameters;
}

ClientsProfiler.prototype.arrayToQuery = function (array) {
    return $.param(array);
}

ClientsProfiler.prototype.goToPage = function (search) {
    location.search = search;
}

ClientsProfiler.prototype.showPopup = function (message) {
    alert(message);
    return this;
}

ClientsProfiler.prototype.openNewWindow = function (url) {
    var newwindow = window.open(url,'vm','height=500,width=800');
    if (window.focus) {newwindow.focus()}
}

ClientsProfiler.prototype.setAlerts = function (error, info, container) {
    var element = $(error + info);
    container.children('.mg-alert').first().append(element);
   // $("#"+container).append(element);
    setTimeout( function(){
        $(element).fadeOut('slow', function() {
            element.remove();
        });
    } , 5000);
}

ClientsProfiler.prototype.appendLoader = function (obj) {
    //$('body').css('cursor', 'progress !important');
    obj.addClass('disabled');
    var loader_html = "<img id=\"mg_loader\" style=\"margin-left: 5px; text-align: center; vertical-align: top;\" src=\"../modules/addons/client_profiler_viewer/views/assets/images/loadingsml.gif\" />" ;
    $(loader_html).load( function() {
        if(!obj.children('img').length) {
            obj.append(loader_html);
        }
    })
    
    return this;
}


ClientsProfiler.prototype.removeLoader = function () {
    //  $('body').css('cursor', 'default');
    $("#mg_loader").parent().first().removeClass('disabled');
    $("#mg_loader").remove();
    return this;
}

//=============================================================================================================
//=========================================MAIN SECTION========================================================
//=============================================================================================================

$(document).ready( function() {
    var profiler = new ClientsProfiler();
    var tooltip_delay;
    var show_time = $('#cp_tooltip_show_time').val();
    var hide_time = $('#cp_tooltip_hide_time').val();
    var post;

    $(document).delegate('a', 'mouseenter', function() {
        var $a = $(this);
        if($a.parents(".CPContainer").length) return;
        tooltip_delay = setTimeout(function() {
            var link_details = profiler.getLinkDetails($a);

            if(!link_details.isLink || !link_details.isClientLink) return ;

            profiler.clearTimer();

            if(link_details.cacheID !== false) {
                profiler.showTooltip(link_details.cacheID);
                return ;
            }
            
           // if(post) post.abort();

            var uid = profiler.addMainTooltip(profiler.loader_html, $a);  
            $("#"+uid).attr('data-clientid', link_details.clientID);
            post = $.post("../modules/addons/client_profiler_viewer/caller.php?module=client_profiler_viewer&page=profiler&ajax=1&_refresh=1&act=get", {id: link_details.clientID})
            .done(function(data) {
                var obj = $.parseJSON(data);
                profiler.setTooltipContent(uid, obj.action.refreshhtml);//addMainTooltip(obj.action.refreshhtml, $a);
               // profiler.showTooltip(a, obj.action.refreshhtml, uid);
            })
            .fail(function() {
                profiler.removeTooltip(uid);
            })
        }, show_time);
    });
    
    $(document).delegate('.CPContainer div.wmc', 'click', function( e ) {
        if($(this).children('div.widget-details-button').length < 1) return ;
        if($(e.target).parents('.CPContainer.details').length > 0 || $(e.target).is('.CPContainer','.details')) return ;
        
        var $main_content = $(this);//.parents('div.wmc').first();
        var $details_button = $main_content.children('div.widget-details-button').first();
        
        $details_button.html('--');
        
        if($main_content.attr('data-cpid')) {
            if($('#' + $main_content.data('cpid')).is(':visible')) {
                profiler.hideDetails();
            } else {
                profiler.showDetails($main_content.attr('data-cpid'));
            }
            
            return; 
        }
        
        var widget = $main_content.data('widget');
        var id = $main_content.parents('.tool-tip-output').data('uid');
        
        profiler.hideDetails();
        var uid = profiler.addTooltipDetails(profiler.loader_html, $main_content, $main_content.parents(".CPContainer").first().attr("id"), widget);
        $("#"+uid).attr('data-clientid', id);
        $.post("../modules/addons/client_profiler_viewer/caller.php?module=client_profiler_viewer&page=profiler&ajax=1&act=details", {id: id, widget: widget})
        .done( function(data) {
            var obj = $.parseJSON(data);
            profiler.setTooltipContent(uid, obj.action.output.page);
           // profiler.addTooltipDetails(obj.action.output.page, $main_content, $main_content.parents(".CPContainer").first().attr("id"));
        })
        .fail(function() {
            //alert("");
        })
    });
    
    $(document).delegate('body', 'click', function( e ) {
        if($(e.target).parents('.CPContainer').length < 1) profiler.hideTolltips();
     });
    
    $('#cp_tooltip_hide').each( function() {
        if($(this).val() == 1) {
            $(document).delegate('a, .CPContainer', 'mouseleave', function() {
                profiler.startTimer(hide_time);
            });

            $(document).delegate('.CPContainer', 'mouseover', function() {
                profiler.clearTimer();
            });
            $(document).delegate('.CPContainer', 'contextmenu', function() {
                hide_time=4000;     
            });
        }
    });
    
    $(document).delegate('a', 'mouseleave', function() {
        if (tooltip_delay) {
            clearTimeout(tooltip_delay);
        }
    });
    
    $(document).delegate('.CPContainer div.widget-close-button', 'click', function(){
        profiler.hideTolltips();
    });
    
    $(document).delegate(".CPContainer .show_more_info",'click', function( e ) {
        e.preventDefault();
        var a = $(this);
        var lang = a.data('lang');
        a.data('lang', a.text());
        if($(".more", a.parent().children('.information-container').first()).toggle().is(':visible')) {
            a.html(lang);
        } else {
            a.html(lang);
        }
    });
    
    $(document).delegate('.CPContainer [data-subact]:not(.disable)', 'click', function( e ){
        e.preventDefault();
        profiler.doAction($(this));
        
    });
    
    $(document).delegate('.CPContainer div.mg-alert div', 'click', function( e ){
        var $this = $(this);
        $this.fadeOut('slow', function() {
            $this.remove();
        });
    });
    
});

$(document).ready(function() {
    var clients = [];
    var htmls = [];
    var as = [];
    var count = 0;
    var last_tr = false;
    var column = 0;
    var columns = [];
    
    $('a', document).each(function() {
        var a = $(this);
        var link = $(this).attr('href');
        if (!link) {
             return true;
        }
        
        var split = link.split('?');
        
        if (split[0] !== 'clientssummary.php' || a.text() === 'Summary' || a.attr('id') === 'summary-reset-password' || a.text().replace(/ /g, '') === 'ActivateasAffiliate') {
            return;
        }
        
        var a = $(this);
        var link = $(this).attr('href');
        var split = link.split('?');
        var id = split[1].split('=')[1];
       
        var tr = a.parents('tr').first();
        
        if(last_tr === false) {
            last_tr = tr;
        }
        
        if( tr.get(0) === last_tr.get(0)) {
            column ++;
        } else {
            column = 1;
            last_tr = tr;
        }
       
        clients[count] = id;
        columns[count] = column;
        htmls[count] = $("<div />").append(a.clone()).html();
        as[count] = a;
        count++;
        
    }).promise().done( function() {
        $.post("../modules/addons/client_profiler_viewer/caller.php?module=client_profiler_viewer&page=profiler&ajax=1&act=inline", 
                    {clients: clients, htmls: htmls, columns: columns})
        .done(function(data) {
            var obj = $.parseJSON(data);
            if(obj.result) {
                $.each(obj.action.output.newhtmls, function(k , v) {
                    as[k].replaceWith(v);
                });
            }
        });
    });
    
    
});